@@ -2,12 +2,13 @@
 implementation of page objects, element(s) and sections
 """
 
-import collections
 import contextlib
 import inspect
 import threading
 import types
 import weakref
+from collections import OrderedDict
+from collections.abc import Sequence
 from functools import wraps
 
 import selenium.webdriver.common.by
@@ -19,22 +20,10 @@ from selenium.common.exceptions import (
 )
 from selenium.webdriver.remote.webelement import WebElement
 from selenium.webdriver.support.ui import WebDriverWait
-from six import add_metaclass
 
 from holmium.core.conditions import BaseCondition
 
 from .enhancers import get_enhancers
-
-if hasattr(collections, "OrderedDict"):
-    OrderedDict = collections.OrderedDict  # pragma: no cover
-else:
-    from ordereddict import OrderedDict  # pragma: no cover
-
-try:
-    from collections.abc import Sequence  # pragma: no cover
-except ImportError:
-    from collections import Sequence  # pragma: no cover
-
 from .facets import CopyOnCreateFacetCollectionMeta, ElementFacet, Faceted
 from .logger import log
 
@@ -99,13 +88,12 @@ class Registry(CopyOnCreateFacetCollectionMeta):
     pages = {}
 
     def __new__(mcs, *args, **kwargs):
-        page = super(Registry, mcs).__new__(mcs, *args, **kwargs)
+        page = super().__new__(mcs, *args, **kwargs)
         Registry.pages[args[0]] = page
         return page
 
 
-@add_metaclass(Registry)
-class Page(Faceted):
+class Page(Faceted, metaclass=Registry):
     """
     Base class for all page objects to extend from.
     void Instance methods implemented by subclasses are provisioned
@@ -129,7 +117,7 @@ class Page(Faceted):
 
     def __init__(self, driver, url=None, iframe=None):
         # pylint: disable=too-many-branches
-        super(Page, self).__init__()
+        super().__init__()
         self.driver = driver
         self.touched = False
         self.initialized = False
@@ -235,7 +223,7 @@ class Page(Faceted):
             return attr
 
 
-class ElementGetter(object):
+class ElementGetter:
     """
     internal class to encapsulate the logic used by
     :class:`holmium.core.Element`
@@ -466,7 +454,7 @@ class Elements(ElementGetter):
         facet=False,
         filter_by=lambda el: el is not None,
     ):
-        super(Elements, self).__init__(
+        super().__init__(
             locator_type,
             query_string,
             base_element=base_element,
@@ -547,7 +535,7 @@ class ElementMap(Elements):
         facet=False,
         filter_by=lambda el: el is not None,
     ):
-        super(ElementMap, self).__init__(
+        super().__init__(
             locator_type,
             query_string,
             base_element,
@@ -596,7 +584,7 @@ class Section(Faceted):
     """
 
     def __init__(self, locator_type, query_string, iframe=None, timeout=0):
-        super(Section, self).__init__()
+        super().__init__()
         self.touched = False
         self.locator_type = locator_type
         self.query_string = query_string
@@ -675,7 +663,7 @@ class Sections(Section, Sequence):
     """
 
     def __init__(self, locator_type, query_string, iframe=None, timeout=0):
-        super(Sections, self).__init__(locator_type, query_string, iframe, timeout)
+        super().__init__(locator_type, query_string, iframe, timeout)
 
     def __getelements__(self):
         if self.timeout:
